-
Notifications
You must be signed in to change notification settings - Fork 3
Expand file tree
/
Copy pathindex.html
More file actions
313 lines (311 loc) · 25.5 KB
/
Copy pathindex.html
File metadata and controls
313 lines (311 loc) · 25.5 KB
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
<!-- HTML header for doxygen 1.9.1-->
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "https://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<!-- Google tag (gtag.js) -->
<script async src="https://www.googletagmanager.com/gtag/js?id=G-SY496B9L99"></script>
<script>
window.dataLayer = window.dataLayer || [];
function gtag(){dataLayer.push(arguments);}
gtag('js', new Date());
gtag('config', 'G-SY496B9L99');
</script>
<meta http-equiv="Content-Type" content="text/xhtml;charset=UTF-8"/>
<meta http-equiv="X-UA-Compatible" content="IE=9"/>
<meta name="generator" content="Doxygen 1.16.1"/>
<meta name="viewport" content="width=device-width, initial-scale=1"/>
<title>MFC: MFC Simulation</title>
<meta name="description" content="MFC Simulation — MFC documentation. Open-source exascale multiphase flow solver." />
<meta name="keywords" content="exascale, fluid dynamics, cfd, computational fluid dynamics, compressible, hpc, bryngelson, colonius, subgrid, multiphase, frontier, summit, el capitan, aurora, amd gpu, gpu, nvidia"/>
<link href="tabs.css" rel="stylesheet" type="text/css"/>
<script type="text/javascript" src="jquery.js"></script>
<script type="text/javascript" src="dynsections.js"></script>
<link href="navtree.css" rel="stylesheet" type="text/css"/>
<script type="text/javascript" src="navtreedata.js"></script>
<script type="text/javascript" src="navtree.js"></script>
<script type="text/javascript" src="cookie.js"></script>
<link href="search/search.css" rel="stylesheet" type="text/css"/>
<script type="text/javascript" src="search/searchdata.js"></script>
<script type="text/javascript" src="search/search.js"></script>
<script type="text/x-mathjax-config">
MathJax.Hub.Config({
extensions: ["tex2jax.js", "TeX/AMSmath.js", "TeX/AMSsymbols.js"],
jax: ["input/TeX","output/HTML-CSS"],
});
// This file is set as MATHJAX_CODEFILE in the Doxyfile. It configures how
// MathJax renders expressions in Markdown so that it is consistent with GitHub.
MathJax.Hub.Config({
extensions: ["tex2jax.js"],
jax: ["input/TeX", "output/HTML-CSS"],
tex2jax: {
inlineMath: [ ['$', '$'], ["\\(","\\)"] ],
displayMath: [ ['$$','$$'], ["\\[","\\]"] ],
processEscapes: true,
ignoreClass: "line" // Ignore code blocks: https://web.archive.org/web/20120430100225/http://www.mathjax.org/docs/1.1/options/tex2jax.html
},
"HTML-CSS": {
fonts: ["TeX"]
}
});
</script>
<script type="text/javascript" async="async" src="https://cdnjs.cloudflare.com/ajax/libs/mathjax/2.7.5/MathJax.js"></script>
<link href="doxygen.css" rel="stylesheet" type="text/css" />
<link rel="shortcut icon" href="icon.ico" type="image/x-icon" />
<link href="doxygen-awesome.css" rel="stylesheet" type="text/css"/>
<link href="doxygen-awesome-sidebar-only.css" rel="stylesheet" type="text/css"/>
<link href="custom.css" rel="stylesheet" type="text/css"/>
</head>
<body>
<div id="top"><!-- do not remove this div, it is closed by doxygen! -->
<div id="titlearea">
<table cellspacing="0" cellpadding="0">
<tbody>
<tr style="height: 56px;">
<td id="projectlogo"><img alt="Logo" src="icon.ico"/></td>
<td id="projectalign" style="padding-left: 0.5em;">
<div id="projectname">MFC
</div>
<div id="projectbrief">Exascale flow solver</div>
</td>
</tr>
</tbody>
</table>
</div>
<!-- Cross-navigation injected into sidebar via script below -->
<script>
document.addEventListener('DOMContentLoaded', function() {
var nav = document.createElement('div');
nav.id = 'mfc-nav';
var items = [
['../documentation/index.html', 'documentation', 'User Guide'],
['../api/index.html', 'api', 'API Documentation']
];
var path = window.location.pathname;
var apiPaths = ['/api/', '/pre_process/', '/simulation/', '/post_process/'];
for (var i = 0; i < items.length; i++) {
var a = document.createElement('a');
a.href = items[i][0];
a.textContent = items[i][2];
if (items[i][1] === 'api') {
for (var j = 0; j < apiPaths.length; j++) {
if (path.indexOf(apiPaths[j]) !== -1) { a.className = 'active'; break; }
}
} else {
if (path.indexOf('/' + items[i][1] + '/') !== -1) a.className = 'active';
}
nav.appendChild(a);
}
var sideNav = document.getElementById('side-nav');
if (sideNav) sideNav.insertBefore(nav, sideNav.firstChild);
});
</script>
<!-- end header part -->
<!-- Generated by Doxygen 1.16.1 -->
<script type="text/javascript">
var searchBox = new SearchBox("searchBox", "search/",'.html');
</script>
<script type="text/javascript">
$(function() { codefold.init(); });
</script>
<script type="text/javascript" src="menudata.js"></script>
<script type="text/javascript" src="menu.js"></script>
<script type="text/javascript">
$(function() {
initMenu('',true,false,'search.php','Search',true);
$(function() { init_search(); });
});
</script>
<div id="main-nav"></div>
</div><!-- top -->
<div id="side-nav" class="ui-resizable side-nav-resizable">
<div id="nav-tree">
<div id="nav-tree-contents">
<div id="nav-sync" class="sync"></div>
</div>
</div>
<div id="splitbar" style="-moz-user-select:none;"
class="ui-resizable-handle">
</div>
</div>
<script type="text/javascript">
$(function(){initNavTree('index.html','',''); });
</script>
<div id="container">
<div id="doc-content">
<!-- window showing the filter options -->
<div id="MSearchSelectWindow"
onmouseover="return searchBox.OnSearchSelectShow()"
onmouseout="return searchBox.OnSearchSelectHide()"
onkeydown="return searchBox.OnSearchSelectKey(event)">
</div>
<!-- iframe showing the search results (closed by default) -->
<div id="MSearchResultsWindow">
<div id="MSearchResults">
<div class="SRPage">
<div id="SRIndex">
<div id="SRResults"></div>
<div class="SRStatus" id="Loading">Loading...</div>
<div class="SRStatus" id="Searching">Searching...</div>
<div class="SRStatus" id="NoMatches">No Matches</div>
</div>
</div>
</div>
</div>
<div><div class="header">
<div class="headertitle"><div class="title">MFC Simulation </div></div>
</div><!--header-->
<div class="contents">
<div class="textblock"><p>The simulation component is the core flow solver. It advances the governing equations in time using high-order finite-volume methods on structured grids with GPU acceleration via OpenACC/OpenMP offloading.</p>
<h2 class="doxsection"><a class="anchor" id="autotoc_md0"></a>
Modules</h2>
<h3 class="doxsection"><a class="anchor" id="autotoc_md1"></a>
Simulation</h3>
<table class="markdownTable">
<tr class="markdownTableHead">
<th class="markdownTableHeadNone">Module </th><th class="markdownTableHeadNone">Description </th></tr>
<tr class="markdownTableRowOdd">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__acoustic__src.html" title="m_acoustic_src">m_acoustic_src</a> </td><td class="markdownTableBodyNone">One-way acoustic source injection, Maeda and Colonius JCP (2017) </td></tr>
<tr class="markdownTableRowEven">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__body__forces.html" title="m_body_forces">m_body_forces</a> </td><td class="markdownTableBodyNone">Computes gravitational and body force source terms for the momentum equations </td></tr>
<tr class="markdownTableRowOdd">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__bubbles.html" title="m_bubbles">m_bubbles</a> </td><td class="markdownTableBodyNone">Bubble-dynamics procedures for ensemble- and volume-averaged model </td></tr>
<tr class="markdownTableRowEven">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__bubbles__ee.html" title="m_bubbles_ee">m_bubbles_EE</a> </td><td class="markdownTableBodyNone">Computes ensemble-averaged (Euler–Euler) bubble source terms for radius, velocity, pressure, and mass transfer </td></tr>
<tr class="markdownTableRowOdd">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__bubbles__el.html" title="m_bubbles_el">m_bubbles_EL</a> </td><td class="markdownTableBodyNone">Tracks Lagrangian bubbles and couples their dynamics to the Eulerian flow via volume averaging </td></tr>
<tr class="markdownTableRowEven">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__bubbles__el__kernels.html" title="m_bubbles_el_kernels">m_bubbles_EL_kernels</a> </td><td class="markdownTableBodyNone">Kernel functions (Gaussian, delta) that smear Lagrangian bubble effects onto the Eulerian grid </td></tr>
<tr class="markdownTableRowOdd">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__cbc.html" title="m_cbc">m_cbc</a> </td><td class="markdownTableBodyNone">Characteristic boundary conditions (CBC) for slip walls, non-reflecting subsonic inflow/outflow, and supersonic boundaries </td></tr>
<tr class="markdownTableRowEven">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__checker.html" title="m_checker">m_checker</a> </td><td class="markdownTableBodyNone">Validates simulation input parameters for consistency and supported configurations </td></tr>
<tr class="markdownTableRowOdd">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__collisions.html" title="m_collisions">m_collisions</a> </td><td class="markdownTableBodyNone">Ghost-node immersed boundary method: locates ghost/image points, computes interpolation coefficients, and corrects the flow state </td></tr>
<tr class="markdownTableRowEven">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__compute__cbc.html" title="m_compute_cbc">m_compute_cbc</a> </td><td class="markdownTableBodyNone">Characteristic boundary condition (CBC) computations for subsonic inflow, outflow, and slip walls </td></tr>
<tr class="markdownTableRowOdd">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__compute__levelset.html" title="m_compute_levelset">m_compute_levelset</a> </td><td class="markdownTableBodyNone">Computes signed-distance level-set fields and surface normals for immersed-boundary patch geometries </td></tr>
<tr class="markdownTableRowEven">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__data__output.html" title="m_data_output">m_data_output</a> </td><td class="markdownTableBodyNone">Writes solution data, run-time stability diagnostics (ICFL, VCFL, CCFL, Rc), and probe/center-of-mass files </td></tr>
<tr class="markdownTableRowOdd">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__derived__variables.html" title="m_derived_variables">m_derived_variables</a> </td><td class="markdownTableBodyNone">Derives diagnostic flow quantities (vorticity, speed of sound, numerical Schlieren, etc.) from conservative and primitive variables </td></tr>
<tr class="markdownTableRowEven">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__fftw.html" title="m_fftw">m_fftw</a> </td><td class="markdownTableBodyNone">Forward and inverse FFT wrappers (FFTW/cuFFT/hipFFT) for azimuthal Fourier filtering in cylindrical geometries </td></tr>
<tr class="markdownTableRowOdd">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__global__parameters.html" title="m_global_parameters">m_global_parameters</a> </td><td class="markdownTableBodyNone">Global parameters for the computational domain, fluid properties, and simulation algorithm configuration </td></tr>
<tr class="markdownTableRowEven">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__hb__function.html" title="m_hb_function">m_hb_function</a> </td><td class="markdownTableBodyNone">Herschel-Bulkley non-Newtonian viscosity: formula, shear rate, and mixture inverse-Re </td></tr>
<tr class="markdownTableRowOdd">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__hypoelastic.html" title="m_hypoelastic">m_hypoelastic</a> </td><td class="markdownTableBodyNone">Computes hypoelastic stress-rate source terms and damage-state evolution </td></tr>
<tr class="markdownTableRowEven">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__ib__patches.html" title="m_ib_patches">m_ib_patches</a> </td><td class="markdownTableBodyNone">Immersed boundary patch geometry constructors for 2D and 3D shapes </td></tr>
<tr class="markdownTableRowOdd">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__ibm.html" title="m_ibm">m_ibm</a> </td><td class="markdownTableBodyNone">Ghost-node immersed boundary method: locates ghost/image points, computes interpolation coefficients, and corrects the flow state </td></tr>
<tr class="markdownTableRowEven">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__igr.html" title="m_igr">m_igr</a> </td><td class="markdownTableBodyNone">Iterative ghost rasterization (IGR) for sharp immersed boundary treatment </td></tr>
<tr class="markdownTableRowOdd">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__mpi__proxy.html" title="m_mpi_proxy">m_mpi_proxy</a> </td><td class="markdownTableBodyNone">MPI halo exchange, domain decomposition, and buffer packing/unpacking for the simulation solver </td></tr>
<tr class="markdownTableRowEven">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__muscl.html" title="m_muscl">m_muscl</a> </td><td class="markdownTableBodyNone">MUSCL reconstruction with interface sharpening for contact-preserving advection </td></tr>
<tr class="markdownTableRowOdd">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__particle__cloud.html" title="m_particle_cloud">m_particle_cloud</a> </td><td class="markdownTableBodyNone">Generates particle beds by converting particle_cloud patch specifications into individual immersed boundary patches before domain reduction </td></tr>
<tr class="markdownTableRowEven">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__pressure__relaxation.html" title="m_pressure_relaxation">m_pressure_relaxation</a> </td><td class="markdownTableBodyNone">Pressure relaxation for the six-equation multi-component model via Newton–Raphson equilibration and volume-fraction correction </td></tr>
<tr class="markdownTableRowOdd">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__qbmm.html" title="m_qbmm">m_qbmm</a> </td><td class="markdownTableBodyNone">Quadrature-based moment methods (QBMM) for polydisperse bubble moment inversion and transport </td></tr>
<tr class="markdownTableRowEven">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__reactive__burn.html" title="m_reactive_burn">m_reactive_burn</a> </td><td class="markdownTableBodyNone">Condensed-phase reactive burn: a pressure-driven programmed-burn source that converts a "reactant" fluid into a "product" fluid on the multi-fluid model (num_fluids=2, chemistry='F') </td></tr>
<tr class="markdownTableRowOdd">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__rhs.html" title="m_rhs">m_rhs</a> </td><td class="markdownTableBodyNone">Assemble the right-hand side of the governing equations using finite-volume flux differencing, Riemann solvers, and physical source terms </td></tr>
<tr class="markdownTableRowEven">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__riemann__solver__hll.html" title="m_riemann_solver_hll">m_riemann_solver_hll</a> </td><td class="markdownTableBodyNone">HLL approximate Riemann solver, Harten et al </td></tr>
<tr class="markdownTableRowOdd">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__riemann__solver__hllc.html" title="m_riemann_solver_hllc">m_riemann_solver_hllc</a> </td><td class="markdownTableBodyNone">HLLC Riemann solver with contact restoration, Toro et al </td></tr>
<tr class="markdownTableRowEven">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__riemann__solver__hlld.html" title="m_riemann_solver_hlld">m_riemann_solver_hlld</a> </td><td class="markdownTableBodyNone">HLLD approximate Riemann solver for MHD, Miyoshi & Kusano JCP (2005) </td></tr>
<tr class="markdownTableRowOdd">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__riemann__solver__lf.html" title="m_riemann_solver_lf">m_riemann_solver_lf</a> </td><td class="markdownTableBodyNone">Lax-Friedrichs (Rusanov) approximate Riemann solver </td></tr>
<tr class="markdownTableRowEven">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__riemann__solvers.html" title="m_riemann_solvers">m_riemann_solvers</a> </td><td class="markdownTableBodyNone">Approximate and exact Riemann solvers (HLL, HLLC, HLLD, exact) for the multicomponent Navier–Stokes equations </td></tr>
<tr class="markdownTableRowOdd">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__riemann__state.html" title="m_riemann_state">m_riemann_state</a> </td><td class="markdownTableBodyNone">Shared Riemann-solver module state and the per-sweep setup, state-buffer population, viscous source flux, and finalization helpers </td></tr>
<tr class="markdownTableRowEven">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__sim__helpers.html" title="m_sim_helpers">m_sim_helpers</a> </td><td class="markdownTableBodyNone">Simulation helper routines for enthalpy computation, CFL calculation, and stability checks </td></tr>
<tr class="markdownTableRowOdd">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__start__up.html" title="m_start_up">m_start_up</a> </td><td class="markdownTableBodyNone">Reads input files, loads initial conditions and grid data, and orchestrates solver initialization and finalization </td></tr>
<tr class="markdownTableRowEven">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__surface__tension.html" title="m_surface_tension">m_surface_tension</a> </td><td class="markdownTableBodyNone">Computes capillary source fluxes and color-function gradients for the diffuse-interface surface tension model </td></tr>
<tr class="markdownTableRowOdd">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__thinc.html" title="m_thinc">m_thinc</a> </td><td class="markdownTableBodyNone">THINC and MTHINC interface compression for volume fraction sharpening </td></tr>
<tr class="markdownTableRowEven">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__time__steppers.html" title="m_time_steppers">m_time_steppers</a> </td><td class="markdownTableBodyNone">Total-variation-diminishing (TVD) Runge–Kutta time integrators (1st-, 2nd-, and 3rd-order SSP) </td></tr>
<tr class="markdownTableRowOdd">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__viscous.html" title="m_viscous">m_viscous</a> </td><td class="markdownTableBodyNone">Computes viscous stress tensors and diffusive flux contributions for the Navier–Stokes equations </td></tr>
<tr class="markdownTableRowEven">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__weno.html" title="m_weno">m_weno</a> </td><td class="markdownTableBodyNone">WENO/WENO-Z/TENO reconstruction with optional monotonicity-preserving bounds and mapped weights </td></tr>
</table>
<h3 class="doxsection"><a class="anchor" id="autotoc_md2"></a>
Common (shared)</h3>
<table class="markdownTable">
<tr class="markdownTableHead">
<th class="markdownTableHeadNone">Module </th><th class="markdownTableHeadNone">Description </th></tr>
<tr class="markdownTableRowOdd">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__boundary__common.html" title="m_boundary_common">m_boundary_common</a> </td><td class="markdownTableBodyNone">Noncharacteristic and processor boundary condition application for ghost cells and buffer regions </td></tr>
<tr class="markdownTableRowEven">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__boundary__io.html" title="m_boundary_io">m_boundary_io</a> </td><td class="markdownTableBodyNone">Boundary condition restart I/O, capillary/IGR buffer population, and grid-variable buffers </td></tr>
<tr class="markdownTableRowOdd">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__boundary__primitives.html" title="m_boundary_primitives">m_boundary_primitives</a> </td><td class="markdownTableBodyNone">Per-cell noncharacteristic boundary condition primitives applied in the ghost cells </td></tr>
<tr class="markdownTableRowEven">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__checker__common.html" title="m_checker_common">m_checker_common</a> </td><td class="markdownTableBodyNone">Shared input validation checks for grid dimensions and AMD GPU compiler limits </td></tr>
<tr class="markdownTableRowOdd">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__chemistry.html" title="m_chemistry">m_chemistry</a> </td><td class="markdownTableBodyNone">Multi-species chemistry interface for thermodynamic properties, reaction rates, and transport coefficients </td></tr>
<tr class="markdownTableRowEven">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__compile__specific.html" title="m_compile_specific">m_compile_specific</a> </td><td class="markdownTableBodyNone">Platform-specific file and directory operations: create, delete, inquire, getcwd, and basename </td></tr>
<tr class="markdownTableRowOdd">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__constants.html" title="m_constants">m_constants</a> </td><td class="markdownTableBodyNone">Compile-time constant parameters: default values, tolerances, and physical constants </td></tr>
<tr class="markdownTableRowEven">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__delay__file__access.html" title="m_delay_file_access">m_delay_file_access</a> </td><td class="markdownTableBodyNone">Rank-staggered file access delays to prevent I/O contention on parallel file systems </td></tr>
<tr class="markdownTableRowOdd">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__derived__types.html" title="m_derived_types">m_derived_types</a> </td><td class="markdownTableBodyNone">Shared derived types for field data, patch geometry, bubble dynamics, and MPI I/O structures </td></tr>
<tr class="markdownTableRowEven">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__finite__differences.html" title="m_finite_differences">m_finite_differences</a> </td><td class="markdownTableBodyNone">Finite difference operators for computing divergence of velocity fields </td></tr>
<tr class="markdownTableRowOdd">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__global__parameters__common.html" title="m_global_parameters_common">m_global_parameters_common</a> </td><td class="markdownTableBodyNone">Shared global parameters and equation-index setup for all three executables </td></tr>
<tr class="markdownTableRowEven">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__helper.html" title="m_helper">m_helper</a> </td><td class="markdownTableBodyNone">Utility routines for bubble model setup, coordinate transforms, array sampling, and special functions </td></tr>
<tr class="markdownTableRowOdd">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__helper__basic.html" title="m_helper_basic">m_helper_basic</a> </td><td class="markdownTableBodyNone">Basic floating-point utilities: approximate equality, default detection, and coordinate bounds </td></tr>
<tr class="markdownTableRowEven">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__model.html" title="m_model">m_model</a> </td><td class="markdownTableBodyNone">Binary STL file reader and processor for immersed boundary geometry </td></tr>
<tr class="markdownTableRowOdd">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__mpi__common.html" title="m_mpi_common">m_mpi_common</a> </td><td class="markdownTableBodyNone">MPI communication layer: domain decomposition, halo exchange, reductions, and parallel I/O setup </td></tr>
<tr class="markdownTableRowEven">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__nvtx.html" title="m_nvtx">m_nvtx</a> </td><td class="markdownTableBodyNone">NVIDIA NVTX profiling API bindings for GPU performance instrumentation </td></tr>
<tr class="markdownTableRowOdd">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__patch__geometries.html" title="m_patch_geometries">m_patch_geometries</a> </td><td class="markdownTableBodyNone">Contains helper functions specific to various patch gemoetries for determining if a grid cell lies inside of or outside of a patch geometry </td></tr>
<tr class="markdownTableRowEven">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__phase__change.html" title="m_phase_change">m_phase_change</a> </td><td class="markdownTableBodyNone">Phase transition relaxation solvers for liquid-vapor flows with cavitation and boiling </td></tr>
<tr class="markdownTableRowOdd">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__precision__select.html" title="m_precision_select">m_precision_select</a> </td><td class="markdownTableBodyNone">Working-precision kind selection (half/single/double) and corresponding MPI datatype parameters </td></tr>
<tr class="markdownTableRowEven">
<td class="markdownTableBodyNone"><a class="el" href="namespacem__variables__conversion.html" title="m_variables_conversion">m_variables_conversion</a> </td><td class="markdownTableBodyNone">Conservative-to-primitive variable conversion, mixture property evaluation, and pressure computation </td></tr>
</table>
<h2 class="doxsection"><a class="anchor" id="autotoc_md3"></a>
See Also</h2>
<ul>
<li><a href="../documentation/index.html">Home & User Guide</a></li>
<li><a href="../pre_process/index.html">Pre-Process API</a></li>
<li><a href="../post_process/index.html">Post-Process API</a> </li>
</ul>
</div></div><!-- PageDoc -->
<a href="doxygen_crawl.html"></a>
</div><!-- contents -->
</div><!-- doc-content -->
</div><!-- container -->
<!-- HTML footer for doxygen 1.9.1-->
<!-- start footer part -->
<div id="nav-path" class="navpath">
<ul></ul>
</div>
</body>
</html>